@@ -79,10 +79,10 @@ class ValidationContext:
         ocsps: Optional[Iterable[Union[bytes, ocsp.OCSPResponse]]] = None,
         revocation_mode: str = "soft-fail",
         revinfo_policy: Optional[CertRevTrustPolicy] = None,
-        weak_hash_algos: Iterable[str] = None,
+        weak_hash_algos: Optional[Iterable[str]] = None,
         time_tolerance: timedelta = timedelta(seconds=1),
         retroactive_revinfo: bool = False,
-        fetcher_backend: FetcherBackend = None,
+        fetcher_backend: Optional[FetcherBackend] = None,
         acceptable_ac_targets: Optional[ACTargetDescription] = None,
         poe_manager: Optional[POEManager] = None,
         revinfo_manager: Optional[RevinfoManager] = None,
